/**
 * @hidden
 *
 * Interface for content data
 *
 * @internal
 * Limited to Microsoft-internal use
 */
export declare enum ContentItemType {
    EMAIL = "email",
    TEXT = "text",
    MEDIA = "media",
    CALENDAR_INVITE = "calendarInvite",
    WEB_PAGE = "webPage",
    MIXED = "mixed"
}
/**
 * @hidden
 *
 * Common properties for all email content types
 *
 * @internal
 * Limited to Microsoft-internal use
 */
export interface BaseEmailContent {
    subject?: string;
    body?: string;
    sender?: string;
    recipients?: string[];
    cc?: string[];
    bcc?: string[];
    attachments?: string[];
    renderedHtml?: string;
}
/**
 * @hidden
 *
 * Interface for server email content (must have id, receivedTime, sentTime)
 *
 * @internal
 * Limited to Microsoft-internal use
 */
export interface ServerEmailContent extends BaseEmailContent {
    id: string;
    receivedTime?: Date;
    sentTime?: Date;
}
/**
 * @hidden
 *
 * Interface for draft email content (no id, times optional)
 *
 * @internal
 * Limited to Microsoft-internal use
 */
export interface DraftEmailContent extends BaseEmailContent {
    savedTime?: Date;
}
export type EmailContent = ServerEmailContent | DraftEmailContent;
/**
 * @hidden
 *
 * Interface for email content data
 *
 * @internal
 * Limited to Microsoft-internal use
 */
export interface CalendarInviteContent {
    id: string;
    title?: string;
    startTime?: Date;
    endTime?: Date;
    location?: string;
    meetingParameters?: string;
    attendees?: string[];
    organizer?: string;
    body?: string;
    attachments?: string[];
}
/**
 * @hidden
 *
 * Interface for web page content data
 *
 * @internal
 * Limited to Microsoft-internal use
 */
export interface WebPageContent {
    id?: string;
    url: string;
    title?: string;
    data?: string;
    description_for_model?: string;
    description?: string;
    faviconUrl?: string;
}
/**
 * @hidden
 *
 * Interface for user selected content data
 *
 * @internal
 * Limited to Microsoft-internal use
 */
export interface TextSelection {
    content: string;
    source?: EmailContent | WebPageContent | CalendarInviteContent;
}
/**
 * @hidden
 *
 * Interface for image media content
 *
 * @internal
 * Limited to Microsoft-internal use
 */
export interface ImageContent {
    url: string;
    width?: number;
    height?: number;
    fileSize?: number;
    format?: string;
    thumbnailUrl?: string;
}
/**
 * @hidden
 *
 * Interface for audio media content
 *
 * @internal
 * Limited to Microsoft-internal use
 */
export interface AudioContent {
    url: string;
    duration?: number;
    fileSize?: number;
    format?: string;
    transcript?: string;
}
/**
 * @hidden
 *
 * Interface for video media content
 *
 * @internal
 * Limited to Microsoft-internal use
 */
export interface VideoContent {
    url: string;
    width?: number;
    height?: number;
    duration?: number;
    fileSize?: number;
    format?: string;
    thumbnailUrl?: string;
    transcript?: string;
}
/**
 * @hidden
 *
 * Enum for media selection types
 *
 * @internal
 * Limited to Microsoft-internal use
 */
export declare enum MediaSelectionType {
    IMAGE = "image",
    AUDIO = "audio",
    VIDEO = "video"
}
/**
 * @hidden
 *
 * Interface for media selection
 *
 * @internal
 * Limited to Microsoft-internal use
 */
export interface MediaSelection {
    type: MediaSelectionType;
    altText?: string;
    content: ImageContent | AudioContent | VideoContent;
    source?: EmailContent | WebPageContent | CalendarInviteContent;
}
/**
 * @hidden
 *
 * Interface for a catch all type content data
 *
 * @internal
 * Limited to Microsoft-internal use
 */
export interface MixedContent {
    emails?: EmailContent[];
    texts?: TextSelection[];
    media?: (ImageContent | AudioContent | VideoContent)[];
    calendarInvites?: CalendarInviteContent[];
    webPages?: WebPageContent[];
    otherContent?: Array<Record<string, unknown>> | undefined;
}
/**
 * @hidden
 *
 * Interface for content data we get from hub
 *
 * @internal
 * Limited to Microsoft-internal use
 */
export type ContentItem = EmailContent | TextSelection | MediaSelection | CalendarInviteContent | WebPageContent | MixedContent;
export interface Content {
    userAction?: string;
    contentType: ContentItemType.CALENDAR_INVITE | ContentItemType.EMAIL | ContentItemType.MEDIA | ContentItemType.TEXT | ContentItemType.WEB_PAGE | ContentItemType.MIXED;
    formCode?: string;
    contentItems: ContentItem[];
    metadata?: string;
    description?: string;
    error_code?: string;
    status?: string;
}
export interface ContentRequest {
    localEndpointInfo: string;
}
/**
 * @hidden
 *
 * Interface for the response context used during user consent pre-checks.
 * Contains information about the user's consent status and whether to show the consent card.
 *
 * @internal
 * Limited to Microsoft-internal use
 */
export interface PreCheckContextResponse {
    error_code?: string;
    status?: string;
    user_consent: UserConsent;
    show_consent_card: boolean;
}
/**
 * @hidden
 *
 * Enum representing possible user consent states.
 *
 * @internal
 * Limited to Microsoft-internal use
 */
export declare enum UserConsent {
    Accepted = "accepted",
    NotAccepted = "not_accepted"
}
/**
 * @hidden
 *
 * Type for user action handler functions that receive content data.
 *
 * @internal
 * Limited to Microsoft-internal use
 */
export declare enum SidePanelErrorCode {
    ConsentNotAccepted = "consent_not_accepted",
    PageContentBlockedPolicy = "page_content_blocked_policy",
    PageContentBlockedDlp = "page_content_blocked_dlp",
    PageContentTypeNotSupportedYet = "page_content_type_not_supported_yet",
    PageContentSizeNotSupported = "page_content_size_not_supported",
    PageContextChanged = "page_context_changed",
    PageContentExtractionFailed = "page_content_extraction_failed",
    PageContentSizeNotSupportedPDF = "page_content_size_not_supported_pdf",
    NotSupportedOnPlatform = "not_supported_on_platform",
    OtherError = "other_error"
}
/**
 * @hidden
 *
 * Interface for errors related to side panel operations.
 * Contains an error code and an optional message.
 *
 * @internal
 * Limited to Microsoft-internal use
 */
export interface SidePanelError {
    errorCode: SidePanelErrorCode;
    message?: string;
}
/**
 * @hidden
 * @beta
 * Implementation of the SidePanelError interface.
 * This class extends the built-in Error class and includes an error code.
 * It is used to represent errors that occur during side panel operations.
 * The error code can be one of the SidePanelErrorCode values or a general ErrorCode.
 */
export declare class SidePanelErrorImpl extends Error implements SidePanelError {
    errorCode: SidePanelErrorCode;
    constructor(errorCode: SidePanelErrorCode, message?: string);
}
